@@ -110,7 +110,7 @@ Examples:
         if args.hook_config_file:
             import json
 
-            with open(args.hook_config_file, "r") as f:
+            with open(args.hook_config_file, "r", encoding="utf-8") as f:
                 hook_config = json.load(f)
             print(f"🔗 Hook config loaded from: {args.hook_config_file}")
 
@@ -455,7 +455,7 @@ Examples:
 
     try:
         print(f"🚀 Starting {args.name}...", file=sys.stderr)
-        print("📡 Transport: stdio (for Claude Desktop)", file=sys.stderr)
+        print("📡 Transport: stdio", file=sys.stderr)
         print(f"🔍 Search enabled: {not args.no_search}", file=sys.stderr)
 
         if args.categories is not None:
@@ -532,7 +532,7 @@ Examples:
         if args.hook_config_file:
             import json
 
-            with open(args.hook_config_file, "r") as f:
+            with open(args.hook_config_file, "r", encoding="utf-8") as f:
                 hook_config = json.load(f)
             print(
                 f"🔗 Hook config loaded from: {args.hook_config_file}", file=sys.stderr
@@ -930,7 +930,7 @@ Examples:
         if args.hook_config_file:
             import json
 
-            with open(args.hook_config_file, "r") as f:
+            with open(args.hook_config_file, "r", encoding="utf-8") as f:
                 hook_config = json.load(f)
             print(f"🔗 Hook config loaded from: {args.hook_config_file}")
 
