@@ -1,7 +1,7 @@
 """
 FAERS_count_additive_administration_routes
 
-Additive multi-drug data: Enumerate and count administration routes for adverse events across spe...
+Enumerate and count administration routes for adverse events across specified medicinal products....
 """
 
 from typing import Any, Optional, Callable
@@ -10,21 +10,21 @@ from ._shared_client import get_shared_client
 
 def FAERS_count_additive_administration_routes(
     medicinalproducts: list[Any],
-    serious: str,
+    serious: Optional[str] = None,
     *,
     stream_callback: Optional[Callable[[str], None]] = None,
     use_cache: bool = False,
     validate: bool = True,
 ) -> Any:
     """
-    Additive multi-drug data: Enumerate and count administration routes for adverse events across spe...
+    Enumerate and count administration routes for adverse events across specified medicinal products....
 
     Parameters
     ----------
     medicinalproducts : list[Any]
         Array of medicinal product names.
     serious : str
-        Filter by seriousness.
+        Optional: Filter by event seriousness. Omit this parameter if you don't want ...
     stream_callback : Callable, optional
         Callback for streaming output
     use_cache : bool, default False
