@@ -1,7 +1,7 @@
 """
 FAERS_count_drug_routes_by_event
 
-Count the most common routes of administration for drugs involved in adverse event reports. Data ...
+Count the most common routes of administration for drugs involved in adverse event reports. Only ...
 """
 
 from typing import Any, Optional, Callable
@@ -10,21 +10,21 @@ from ._shared_client import get_shared_client
 
 def FAERS_count_drug_routes_by_event(
     medicinalproduct: str,
-    serious: str,
+    serious: Optional[str] = None,
     *,
     stream_callback: Optional[Callable[[str], None]] = None,
     use_cache: bool = False,
     validate: bool = True,
 ) -> Any:
     """
-    Count the most common routes of administration for drugs involved in adverse event reports. Data ...
+    Count the most common routes of administration for drugs involved in adverse event reports. Only ...
 
     Parameters
     ----------
     medicinalproduct : str
         Drug name.
     serious : str
-        Seriousness of event.
+        Optional: Filter by event seriousness. Omit this parameter if you don't want ...
     stream_callback : Callable, optional
         Callback for streaming output
     use_cache : bool, default False
